<?php

/**
 * @file
 * Contains the user title tid filter handler.
 */

/**
 * Filter by title id
 */
class views_handler_filter_user_title_tid extends views_handler_filter_many_to_one {
  function has_extra_options() { return TRUE; }

  function get_value_options() { /* don't overwrite the value options */ }

  function option_definition() {
    $options = parent::option_definition();

    $options['type'] = array('default' => 'textfield');
    $options['rids'] = array('default' => array());

    return $options;
  }

  function extra_options_form(&$form, &$form_state) {
    $roles = user_titles_get_roles();
    foreach ($roles as $rid => $role) {
      $options[$rid] = check_plain($role);
    }

    $form['rids'] = array(
      '#prefix' => '<div class="views-left-40">',
      '#suffix' => '</div>',
      '#type' => 'checkboxes',
      '#title' => t('Roles'),
      '#options' => $options,
      '#description' => t('Select which roles to show terms for in the regular options.'),
      '#default_value' => $this->options['rids'],
    );

    $form['markup_start'] = array(
      '#value' => '<div class="views-left-40">',
    );

    $form['type'] = array(
      '#type' => 'radios',
      '#title' => t('Selection type'),
      '#options' => array('select' => t('Dropdown'), 'textfield' => t('Autocomplete')),
      '#default_value' => $this->options['type'],
    );

    $form['markup_end'] = array(
      '#value' => '</div>',
    );
  }

  function value_form(&$form, &$form_state) {
    $all_roles = user_titles_get_roles();
    $selection = array_filter($this->options['rids']);
    $roles = empty($selection) ? array_keys($all_roles) : $selection;
    $role_names = '';
    $rids = '';
    $in = '';
    $query_vars = array();
    foreach ($roles as $rid) {
      $role_names .= $role_names ? ', ' . $all_roles[$rid] : $all_roles[$rid];
      $rids .= $rids ? ",$rid" : $rid;
      $in .= $in ? ', %d' : '%d';
      $query_vars[] = $rid;
    }

    if ($this->options['type'] == 'textfield') {
      $default = '';
      if ($this->value) {
        if (is_array($this->value)) {
          foreach ($this->value as $tid) {
            $in .= $in ? ', %d' : '%d';
          }
          $result = db_query("SELECT * FROM {user_titles} ut WHERE ut.tid IN ($in)", $this->value);
        }
        else {
          $result = db_query("SELECT * FROM {user_titles} ut WHERE ut.tid = %d", $this->value);
        }

        while ($title = db_fetch_object($result)) {
          $default .= $default ? ", {$title->title}" : $title->title;
        }
      }

      $form['value'] = array(
        '#title' => !empty($selection) ? format_plural(count($selection), 'Select titles from role: @role_names', 'Select titles from roles: @role_names', array('@role_names' => $role_names)) : t('Select titles'),
        '#type' => 'textfield',
        '#default_value' => $default,
      );

      $form['value']['#autocomplete_path'] = 'user-titles/autocomplete/' . $rids;
    }
    else {
      $options = array();
      $result = db_query("SELECT * FROM {user_titles} WHERE rid IN ($in) ORDER BY value", $query_vars);
      while ($title = db_fetch_object($result)) {
        $options[$title->tid] = $title->title;
      }

      $default_value = (array) $this->value;

      if (!empty($form_state['exposed'])) {
        $identifier = $this->options['expose']['identifier'];

        if (!empty($this->options['expose']['reduce'])) {
          $options = $this->reduce_value_options($options);

          if (empty($this->options['expose']['single']) && !empty($this->options['expose']['optional'])) {
            $default_value = array();
          }
        }

        if (!empty($this->options['expose']['single'])) {
          if (!empty($this->options['expose']['optional']) && (empty($default_value) || !empty($this->options['expose']['reduce']))) {
            $default_value = 'All';
          }
          else if (empty($default_value)) {
            $keys = array_keys($options);
            $default_value = array_shift($keys);
          }
          else {
            $copy = $default_value;
            $default_value = array_shift($copy);
          }
        }
      }
      $form['value'] = array(
        '#type' => 'select',
        '#title' => !empty($selection) ? format_plural(count($selection), 'Select titles from role: @role_names', 'Select titles from roles: @role_names', array('@role_names' => $role_names)) : t('Select titles'),
        '#multiple' => TRUE,
        '#options' => $options,
        '#size' => min(9, count($options)),
        '#default_value' => $default_value,
      );

      if (!empty($form_state['exposed']) && !isset($form_state['input'][$identifier])) {
        $form_state['input'][$identifier] = $default_value;
      }
    }

    if (empty($form_state['exposed'])) {
      // Retain the helper option
      $this->helper->options_form($form, $form_state);
    }
  }

  function value_validate(&$form, &$form_state) {
    // We only validate if they've chosen the text field style.
    if ($this->options['type'] != 'textfield') {
      return;
    }

    $values = drupal_explode_tags($form_state['values']['options']['value']);
    $tids = $this->validate_title_strings($form['value'], $values);

    if ($tids) {
      $form_state['values']['options']['value'] = $tids;
    }
  }

  function accept_exposed_input($input) {
    if (empty($this->options['exposed'])) {
      return TRUE;
    }

    // If it's optional and there's no value don't bother filtering.
    if ($this->options['expose']['optional'] && empty($this->validated_exposed_input)) {
      return FALSE;
    }

    $rc = parent::accept_exposed_input($input);
    if ($rc) {
      // If we have previously validated input, override.
      if (isset($this->validated_exposed_input)) {
        $this->value = $this->validated_exposed_input;
      }
    }

    return $rc;
  }

  function exposed_validate(&$form, &$form_state) {
    if (empty($this->options['exposed'])) {
      return;
    }

    $identifier = $this->options['expose']['identifier'];

    // We only validate if they've chosen the text field style.
    if ($this->options['type'] != 'textfield') {
      if ($form_state['values'][$identifier] != 'All')  {
        $this->validated_exposed_input = (array) $form_state['values'][$identifier];
      }
      return;
    }

    if (empty($this->options['expose']['identifier'])) {
      return;
    }

    $values = drupal_explode_tags($form_state['values'][$identifier]);

    $tids = $this->validate_title_strings($form[$identifier], $values);
    if ($tids) {
      $this->validated_exposed_input = $tids;
    }
  }

  /**
   * Validate the user string. Since this can come from either the form
   * or the exposed filter, this is abstracted out a bit so it can
   * handle the multiple input sources.
   */
  function validate_title_strings(&$form, $values) {
    if (empty($values)) {
      return array();
    }

    $tids = array();
    $placeholders = array();
    $query_args = array();
    $results = array();
    $title_in = '';
    foreach ($values as $value) {
      $missing[strtolower($value)] = TRUE;
      $query_args[] = $value;
      $title_in .= $title_in ? ", '%s'" : "'%s'";
    }

    if (!$query_args) {
      return;
    }

    // add the taxonomy vid to the argument list.
    $rid_in = '';
    foreach ($this->options['rids'] as $rid => $value) {
      if ($value) {
        $query_args[] = $rid;
        $rid_in .= $rid_in ? ", %d" : "%d";
      }
    }

    if ($rid_in) {
      $result = db_query("SELECT * FROM {user_titles} WHERE title IN ($title_in) AND rid IN ($rid_in)", $query_args);
    }
    else {
      $result = db_query("SELECT * FROM {user_titles} WHERE title IN ($title_in)", $query_args);
    }
    while ($title = db_fetch_object($result)) {
      unset($missing[strtolower($title->title)]);
      $tids[] = $title->tid;
    }

    if ($missing) {
      form_error($form, format_plural(count($missing), 'Unable to find title: @titles', 'Unable to find titles: @titles', array('@titles' => implode(', ', array_keys($missing)))));
    }

    return $tids;
  }

  function value_submit($form, &$form_state) {
    // prevent array_filter from messing up our arrays in parent submit.
  }

  function expose_form_right(&$form, &$form_state) {
    parent::expose_form_right($form, $form_state);
    if ($this->options['type'] != 'select') {
      unset($form['expose']['reduce']);
    }
  }

  function admin_summary() {
    // set up $this->value_options for the parent summary
    $this->value_options = array();

    if ($this->value) {
      if (is_array($this->value)) {
        foreach ($this->value as $tid) {
          $in .= $in ? ', %d' : '%d';
        }
        $result = db_query("SELECT * FROM {user_titles} ut WHERE ut.tid IN ($in)", $this->value);
      }
      else {
        $result = db_query("SELECT * FROM {user_titles} ut WHERE ut.tid = %d", $this->value);
      }

      while ($title = db_fetch_object($result)) {
        $this->value_options[$title->tid] = $title->title;
      }
    }
    return parent::admin_summary();
  }
}
