<?php

/**
 * @file
 * Contains the user title image sort handler.
 */

/**
 * Sort handler for user title images.
 *
 * This handler enables the user to select from a couple of different sort options.
 *
 * @ingroup views_sort_handlers
 */
class views_handler_sort_user_title_image extends views_handler_sort {
  function option_definition() {
    $options = parent::option_definition();

    $options['sort_by'] = array('default' => 'has_image');

    return $options;
  }

  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    $form['sort_by'] = array(
      '#type' => 'radios',
      '#title' => t('Sort by'),
      '#options' => array(
        'has_image' => t('Has image?'),
        'file_path' => t('File path'),
      ),
      '#description' => t('How to sort. Either by whether or not there is a file or by the file name.'),
      '#default_value' => $this->options['sort_by'],
    );
  }

  /**
   * Called to add the sort to a query.
   */
  function query() {
    $this->ensure_my_table();
    switch ($this->options['sort_by']) {
      case 'has_image':
      default:
        $formula = "IF(CHAR_LENGTH($this->table_alias.$this->real_field) > 0, 1, 0)";
        $this->query->add_orderby(NULL, $formula, $this->options['order'], $this->table_alias . '_' . $this->field . '_' . $this->options['sort_by']);
        return;
      case 'file_path':
        $this->query->add_orderby($this->table_alias, $this->real_field, $this->options['order']);
        return;
    }
  }
}
